core.Workflow (Workflow) — amici1

# `core.Workflow` (Workflow)

Actions

A workflow is a specialized choicelist used for defining the states of a workflow. Every choice is an instance of `State`.

verbose_name

  The translatable designation for a given state in this workflow.

verbose_name_plural

  The translatable designation for the set of existing states in this workflow.

  The default value for this is built during startup: if the workflow is being used on a single model (which is the case for most workflows), the default text is « {} states » where {} is the model’s verbose name.

## Filter parameters